@@ -1,5 +1,4 @@
 import enum
-from dataclasses import dataclass
 
 from easy_pysy.core import logging
 from easy_pysy.core.event import Event, emit
@@ -35,9 +34,14 @@ def start():
 
 def stop():
     require(context.state == AppState.STARTED, f"Can't stop application, current state: {context.state}")
-    logging.info(f'Stopping')
-    context.state = AppState.STOPPING
-    emit(AppStopping())
+
+
+    try:
+        logging.info(f'Stopping')
+        context.state = AppState.STOPPING
+        emit(AppStopping())
+    except BaseException:
+        logging.exception('Error while stopping application ! Some AppStopping subscribers may not have been called')
 
     logging.info('Stopped')
     context.state = AppState.STOPPED
@@ -49,17 +53,14 @@ def shutdown(exit_code=0):
     exit(exit_code)
 
 
-@dataclass
 class AppStarting(Event):
     pass
 
 
-@dataclass
 class AppStarted(Event):
     pass
 
 
-@dataclass
 class AppStopping(Event):
     pass
 
